==> react-talend-components-0.75.1.tgz: package/src/Drawer/Drawer.component.js <==
import React, { PropTypes } from 'react';
import { CSSTransition, transit } from 'react-css-transition';
import classnames from 'classnames';
import ActionBar from '../ActionBar';
import Action from '../Actions/Action';
import TabBar from '../TabBar';

import theme from './Drawer.scss';

class DrawerAnimation extends React.Component {

	constructor(props) {
		super(props);
		this.handleTransitionComplete = this.handleTransitionComplete.bind(this);
		this.state = { transitioned: false };
	}

	handleTransitionComplete() {
		this.props.onTransitionComplete();
		this.setState({ transitioned: true });
	}

	render() {
		const { children, ...rest } = this.props;
		return (
			<CSSTransition
				{...rest}
				onTransitionComplete={this.handleTransitionComplete}
				defaultStyle={{ transform: 'translateX(100%)' }}
				enterStyle={{ transform: transit('translateX(0%)', 350, 'ease-in-out') }}
				leaveStyle={{ transform: transit('translateX(100%)', 350, 'ease-in-out') }}
				activeStyle={{ transform: 'translateX(0%)' }}
			>
				{React.cloneElement(children, this.state)}
			</CSSTransition>
		);
	}

}

DrawerAnimation.propTypes = {
	children: PropTypes.node,
	onTransitionComplete: PropTypes.func.isRequired,
};

function DrawerContainer({ stacked, className, children, withTransition = true, ...rest }) {
	const drawerContainerClasses = classnames(
		theme['tc-drawer'],
		className,
		'tc-drawer',
		{
			[theme['tc-drawer-transition']]: withTransition,
			'tc-drawer-transition': withTransition,
		},
		{
			[theme['drawer-stacked']]: stacked,
			stacked,
		});
	return (
		<div className={drawerContainerClasses} {...rest}>
			<div className={theme['tc-drawer-container']}>
				{children}
			</div>
		</div>
	);
}

DrawerContainer.propTypes = {
	stacked: PropTypes.bool,
	withTransition: PropTypes.bool,
	className: PropTypes.string,
	children: PropTypes.node.isRequired,
};

export function cancelActionComponent(onCancelAction) {
	if (!onCancelAction) {
		return null;
	}
	const enhancedCancelAction = Object.assign({
		icon: 'talend-cross',
		hideLabel: true,
		link: true,
	}, onCancelAction);
	return <Action className={theme['tc-drawer-close-action']} {...enhancedCancelAction} />;
}

function DrawerTitle({ title, children, onCancelAction }) {
	if (!title) {
		return null;
	}
	return (
		<div>
			<div className={theme['tc-drawer-header']}>
				<h1>{title}</h1>
				{cancelActionComponent(onCancelAction)}
			</div>
			<div className={theme['tc-drawer-header-with-tabs']}>
				{children}
			</div>
		</div>
	);
}

DrawerTitle.propTypes = {
	title: PropTypes.string.isRequired,
	onCancelAction: PropTypes.shape(Action.propTypes),
	children: PropTypes.node,
};

function DrawerContent({ children, ...rest }) {
	return (
		<div className={theme['tc-drawer-content']} {...rest}>
			{children}
		</div>
	);
}

DrawerContent.propTypes = {
	children: PropTypes.node,
};

function DrawerFooter({ children }) {
	return (
		<div className={theme['tc-drawer-footer']}>
			{children}
		</div>
	);
}

DrawerFooter.propTypes = {
	children: PropTypes.node,
};

function combinedFooterActions(onCancelAction, footerActions) {
	if (!onCancelAction) {
		return footerActions;
	}
	const enhancedFooterActions = Object.assign({}, footerActions);
	if (footerActions && footerActions.actions && footerActions.actions.left) {
		enhancedFooterActions.actions.left.push(onCancelAction);
	} else {
		enhancedFooterActions.actions.left = [].push(onCancelAction);
	}
	return enhancedFooterActions;
}

function Drawer({
	stacked,
	title,
	className,
	style,
	children,
	footerActions,
	onCancelAction,
	tabs,
	withTransition = true,
}) {
	if (!children) {
		return null;
	}
	return (
		<DrawerContainer
			stacked={stacked}
			className={className}
			style={style}
			withTransition={withTransition}
		>
			<DrawerTitle title={title} onCancelAction={onCancelAction} />
			{tabs && (<TabBar {...tabs} />)}
			<div style={{ display: 'flex', flexDirection: 'column', flexGrow: 1, overflow: 'hidden' }}>
				<DrawerContent>
					{children}
				</DrawerContent>
				<ActionBar {...combinedFooterActions(onCancelAction, footerActions)} />
			</div>
		</DrawerContainer>
	);
}

Drawer.propTypes = {
	stacked: PropTypes.bool,
	title: PropTypes.string,
	children: PropTypes.node,
	style: PropTypes.object,  // eslint-disable-line react/forbid-prop-types
	className: PropTypes.string,
	// footer action, see action bar for api
	footerActions: PropTypes.shape(ActionBar.propTypes).isRequired,
	onCancelAction: PropTypes.shape(Action.propTypes),
	tabs: PropTypes.shape(TabBar.propTypes),
	withTransition: PropTypes.bool,
};

Drawer.Animation = DrawerAnimation;
Drawer.Container = DrawerContainer;
Drawer.Title = DrawerTitle;
Drawer.Content = DrawerContent;
Drawer.Footer = DrawerFooter;
Drawer.FooterStyle = theme['tc-drawer-footer'];

export default Drawer;

==> react-talend-components-0.85.1.tgz: package/src/Drawer/Drawer.component.js <==
import React, { PropTypes } from 'react';
import { CSSTransition, transit } from 'react-css-transition';
import classnames from 'classnames';
import ActionBar from '../ActionBar';
import Action from '../Actions/Action';
import TabBar from '../TabBar';

import theme from './Drawer.scss';

class DrawerAnimation extends React.Component {

	constructor(props) {
		super(props);
		this.handleTransitionComplete = this.handleTransitionComplete.bind(this);
		this.state = { transitioned: false };
	}

	handleTransitionComplete() {
		this.props.onTransitionComplete();
		this.setState({ transitioned: true });
	}

	render() {
		const { children, ...rest } = this.props;
		return (
			<CSSTransition
				{...rest}
				onTransitionComplete={this.handleTransitionComplete}
				defaultStyle={{ transform: 'translateX(100%)' }}
				enterStyle={{ transform: transit('translateX(0%)', 350, 'ease-in-out') }}
				leaveStyle={{ transform: transit('translateX(100%)', 350, 'ease-in-out') }}
				activeStyle={{ transform: 'translateX(0%)' }}
			>
				{React.cloneElement(children, this.state)}
			</CSSTransition>
		);
	}

}

DrawerAnimation.propTypes = {
	children: PropTypes.node,
	onTransitionComplete: PropTypes.func,
};
DrawerAnimation.defaultProps = {
	onTransitionComplete: () => {},
};

function DrawerContainer({ stacked, className, children, withTransition = true, ...rest }) {
	const drawerContainerClasses = classnames(
		theme['tc-drawer'],
		className,
		'tc-drawer',
		{
			[theme['tc-drawer-transition']]: withTransition,
			'tc-drawer-transition': withTransition,
		},
		{
			[theme['drawer-stacked']]: stacked,
			stacked,
		});
	return (
		<div className={drawerContainerClasses} {...rest}>
			<div className={theme['tc-drawer-container']}>
				{children}
			</div>
		</div>
	);
}

DrawerContainer.propTypes = {
	stacked: PropTypes.bool,
	withTransition: PropTypes.bool,
	className: PropTypes.string,
	children: PropTypes.node.isRequired,
};

export function cancelActionComponent(onCancelAction) {
	if (!onCancelAction) {
		return null;
	}
	const enhancedCancelAction = Object.assign({
		icon: 'talend-cross',
		hideLabel: true,
		link: true,
	}, onCancelAction);
	return <Action className={theme['tc-drawer-close-action']} {...enhancedCancelAction} />;
}

function DrawerTitle({ title, children, onCancelAction }) {
	if (!title) {
		return null;
	}
	return (
		<div>
			<div className={theme['tc-drawer-header']}>
				<h1>{title}</h1>
				{cancelActionComponent(onCancelAction)}
			</div>
			<div className={theme['tc-drawer-header-with-tabs']}>
				{children}
			</div>
		</div>
	);
}

DrawerTitle.propTypes = {
	title: PropTypes.string.isRequired,
	onCancelAction: PropTypes.shape(Action.propTypes),
	children: PropTypes.node,
};

function DrawerContent({ children, ...rest }) {
	return (
		<div className={theme['tc-drawer-content']} {...rest}>
			{children}
		</div>
	);
}

DrawerContent.propTypes = {
	children: PropTypes.node,
};

function DrawerFooter({ children }) {
	return (
		<div className={theme['tc-drawer-footer']}>
			{children}
		</div>
	);
}

DrawerFooter.propTypes = {
	children: PropTypes.node,
};

function combinedFooterActions(onCancelAction, footerActions) {
	if (!onCancelAction) {
		return footerActions;
	}
	const enhancedFooterActions = Object.assign({}, footerActions);
	if (footerActions && footerActions.actions && footerActions.actions.left) {
		enhancedFooterActions.actions.left.push(onCancelAction);
	} else {
		enhancedFooterActions.actions.left = [].push(onCancelAction);
	}
	return enhancedFooterActions;
}

function Drawer({
	stacked,
	title,
	className,
	style,
	children,
	footerActions,
	onCancelAction,
	tabs,
	withTransition = true,
}) {
	if (!children) {
		return null;
	}
	return (
		<DrawerContainer
			stacked={stacked}
			className={className}
			style={style}
			withTransition={withTransition}
		>
			<DrawerTitle title={title} onCancelAction={onCancelAction} />
			{tabs && (<TabBar {...tabs} />)}
			<div style={{ display: 'flex', flexDirection: 'column', flexGrow: 1, overflow: 'hidden' }}>
				<DrawerContent>
					{children}
				</DrawerContent>
				<ActionBar {...combinedFooterActions(onCancelAction, footerActions)} />
			</div>
		</DrawerContainer>
	);
}

Drawer.propTypes = {
	stacked: PropTypes.bool,
	title: PropTypes.string,
	children: PropTypes.node,
	style: PropTypes.object,  // eslint-disable-line react/forbid-prop-types
	className: PropTypes.string,
	// footer action, see action bar for api
	footerActions: PropTypes.shape(ActionBar.propTypes).isRequired,
	onCancelAction: PropTypes.shape(Action.propTypes),
	tabs: PropTypes.shape(TabBar.propTypes),
	withTransition: PropTypes.bool,
};

Drawer.Animation = DrawerAnimation;
Drawer.Container = DrawerContainer;
Drawer.Title = DrawerTitle;
Drawer.Content = DrawerContent;
Drawer.Footer = DrawerFooter;
Drawer.FooterStyle = theme['tc-drawer-footer'];

export default Drawer;
